@@ -304,7 +304,7 @@ extern ssize_t 	iconv_list_size;
 	int	partial_code_point	(const char *);
 	int	quick_display_column_count 	(const char *);
 	int	input_column_count 	(const char *);
-	int	ucs_to_utf8 		(u_32int_t, char *, size_t);
+	int	ucs_to_utf8 		(uint32_t, char *, size_t);
 	int	grab_codepoint 		(const char *x);
 	int     quick_code_point_count	(const char *str);
 	int     previous_code_point2	(const char *, const char *, ptrdiff_t *);
@@ -323,7 +323,7 @@ extern ssize_t 	iconv_list_size;
 	void	init_recodings		(void);
 const 	char *	find_recoding		(const char *, iconv_t *, iconv_t *);
 	char *	recode_message		(const char *, const char *, const char *, const char **, int);
-	int    	ucs_to_console 		(u_32int_t, char *, size_t);
+	int    	ucs_to_console 		(uint32_t, char *, size_t);
 	BUILT_IN_COMMAND(encoding);
 const 	char *	outbound_recode 	(const char *, int, const char *, char **);
 const 	char *	inbound_recode 		(const char *, int, const char *, const char *, char **);
