@@ -20,15 +20,14 @@
 typedef struct
 {
 	char	*name;
-	u_32int_t hash;
 	char	*value;
-} MAY_ALIAS A005_item;
+} A005_item;
 
 typedef struct WaitCmdstru
 {
         char    *stuff;
         struct  WaitCmdstru *next;
-} MAY_ALIAS WaitCmd;
+} WaitCmd;
 
 typedef struct ServerInfo 
 {
