@@ -143,8 +143,8 @@ static char *who_item_full_desc (WhoEntry *item)
 		"dalnet [%d], dalnet_args [%s], who_mask [%d], "
 		"who_target [%s], who_name [%s], who_host [%s], "
 		"who_server [%s], who_nick [%s], who_real [%s], "
-		"who_stuff [%s], who_end [%s], next [%p], line [%p], "
-		"end [%p], requested ["INTMAX_FORMAT"], dirty ["INTMAX_FORMAT"]",
+		"who_stuff [%s], who_end [%s], next [%p], line [%s], "
+		"end [%s], requested ["INTMAX_FORMAT"], dirty ["INTMAX_FORMAT"]",
 			item->refnum,
 			item->dirty, item->piggyback, item->undernet_extended, 
 				S(item->undernet_extended_args),
@@ -155,8 +155,9 @@ static char *who_item_full_desc (WhoEntry *item)
 			S(item->who_server), S(item->who_nick), 
 				S(item->who_real),
 			S(item->who_stuff), S(item->who_end), 
-				item->next, item->line,
-			item->end, 
+				(void *)item->next, 
+			item->line ? "<internal>" : "<none>",
+			item->end ? "<internal>" : "<none>",
 			(intmax_t) item->request_time.tv_sec,
 			(intmax_t) item->dirty_time.tv_sec);
 	else
@@ -173,7 +174,7 @@ static char *who_item_desc (WhoEntry *item)
 	    snprintf(retval, sizeof retval, 
 		"refnum [%d] dirty [%d], piggyback [%d], next [%p]",
 			item->refnum,
-			item->dirty, item->piggyback, item->next);
+			item->dirty, item->piggyback, (void *)item->next);
 	else
 	    snprintf(retval, sizeof retval, "<none>");
 
@@ -201,7 +202,6 @@ static WhoEntry *who_queue_top (int refnum)
 static WhoEntry *who_previous_query (int refnum, WhoEntry *me)
 {
 	WhoEntry *what;
-	Server *s;
 
 	if (!get_server(refnum))
 		return NULL;
@@ -713,7 +713,6 @@ static	int	last_width = -1;
 	char 	*name;
 	WhoEntry *new_w = who_queue_top(refnum);
 	int	l;
-	char 	*extra = NULL;
 
 	if (!new_w)
 	{
@@ -1181,7 +1180,6 @@ static IsonEntry *ison_wait_top (int refnum)
 
 static IsonEntry *get_new_ison_entry (int refnum, int next)
 {
-	Server *s;
 	IsonEntry *new_w;
 
 	if (!get_server(refnum))
@@ -1210,14 +1208,14 @@ static void ison_queue_list (int refnum)
 
 	for (item = s->ison_queue; item; item = item->next, count++)
 	{
-		yell("[%d] [%s] [%p]", count, item->ison_asked, 
-				item->line);
+		yell("[%d] [%s] ["UINTMAX_HEX_FORMAT"]", count, item->ison_asked, 
+				(uintmax_t)item->line);
 	}
 
 	for (item = s->ison_wait; item; item = item->next, count++)
 	{
-		yell("[%d] [%s] [%p] (pending)", count, item->ison_asked, 
-				item->line);
+		yell("[%d] [%s] ["UINTMAX_HEX_FORMAT"] (pending)", count, item->ison_asked, 
+				(uintmax_t)item->line);
 	}
 }
 
@@ -1729,7 +1727,6 @@ void userhostbase (int refnum, char *args, const char *subargs, void (*line) (in
 			UserhostEntry *new_u = get_new_userhost_entry(refnum);
 
 			move_to_abs_word(ptr, (const char **)&next_ptr, count);
-
 			if (next_ptr && *next_ptr && next_ptr > ptr)
 				next_ptr[-1] = 0;
 
